## Changelog

Richard de Vos <rdevos72@gmail.com>
fhs_xmltv_tools
fhs-xmltv-tools

--------------------------------------------------------------
- 0.1.0: initial creation
- 0.1.1: add basic search options
- 0.1.2: add join-xml-files
- 0.1.3: add run-task functionality with yaml task file
- 0.1.4: fix readme install instructions
- 0.1.5: add analyse_programs to playyaml
- 0.1.6: add execute_command tasks types and add tagging options for tags
